yt.data\_objects.region\_expression module
==========================================

.. automodule:: yt.data_objects.region_expression
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
